@@ -45,7 +45,7 @@ sub _post_to_irc {
     my $token = sha1_hex($message, $cfg->{secret});
     my $res = $ua->get($cfg->{host}.'?message='.$message.'&token='.$token);
     unless ($res->is_success) {
-        say "Could not post to IRC...";
+        error_message('Could not post to IRC: %s',$res->status);
     }
 }
 
@@ -62,7 +62,7 @@ App::TimeTracker::Command::Post2IRC - App::TimeTracker plugin for posting to IRC
 
 =head1 VERSION
 
-version 2.009
+version 2.010
 
 =head1 DESCRIPTION
 
@@ -79,28 +79,24 @@ The messages is transfered as a GET-Request like this:
 
 =head1 CONFIGURATION
 
-=over
+=head2 plugins
 
-=item * add C<Post2IRC> to your list of plugins
+add C<Post2IRC> to your list of plugins
 
-=item * add a hash named C<post2irc>, containing the following keys:
+=head2 post2irc
 
-=over
+add a hash named C<post2irc>, containing the following keys:
 
-=item * host
+=head3 host
 
 The hostname of the server C<Bot::FromHTTP> is running on. Might also contain a special port number (C<http://ircbox.vpn.yourcompany.com:9090>)
 
-=item secret
+=head3 secret
 
 A shared secret used to calculate the authentification token. The token is calculated like this:
 
   my $token = Digest::SHA1::sha1_hex($message, $secret);
 
-=back
-
-=back
-
 =head1 NEW COMMANDS
 
 none
@@ -112,18 +108,14 @@ none
 After running the respective command, a message is sent to the
 webservice that will afterwards post the message to IRC.
 
-B<New Options>:
+=head3 New Options
 
-=over
-
-=item --irc_quiet
+=head4 --irc_quiet
 
     ~/perl/Your-Project$ tracker start --irc_quiet
 
 Do not post this action to IRC.
 
-=back
-
 =head1 AUTHOR
 
 Thomas Klausner <domm@cpan.org>
