@@ -5,6 +5,8 @@ use 5.010;
 
 # ABSTRACT: App::TimeTracker Proto Class
 
+use App::TimeTracker::Utils qw(error_message);
+
 use Moose;
 use MooseX::Types::Path::Class;
 use File::HomeDir ();
@@ -68,6 +70,11 @@ sub run {
 
     my $config = $self->load_config;
 
+    # unique plugins
+    $config->{plugins} ||= [];
+    my %plugins_unique = map {$_ =>  1} @{$config->{plugins}};
+    $config->{plugins} = [ keys %plugins_unique ];
+
     my $class = Moose::Meta::Class->create_anon_class(
         superclasses => ['App::TimeTracker'],
         roles        => [
@@ -81,6 +88,7 @@ sub run {
         $method =~ s/^cmd_//;
         $commands{$method}=1;
     }
+
     my $load_attribs_for_command;
     foreach (@ARGV) {
         if ($commands{$_}) {
@@ -91,11 +99,12 @@ sub run {
     if ($load_attribs_for_command && $class->has_method($load_attribs_for_command)) {
         $class->name->$load_attribs_for_command($class);
     }
+    $class->make_immutable();
 
     $class->name->new_with_options( {
             home            => $self->home,
             config          => $config,
-            _currentproject => $self->project,
+            ($self->has_project ? (_current_project=> $self->project) : ()),
         } )->run;
 }
 
@@ -104,24 +113,61 @@ sub load_config {
     $dir ||= Path::Class::Dir->new->absolute;
     my $config={};
     my @used_config_files;
+    my $cfl = $self->config_file_locations;
+
+    my $project;
+    my $projects = $self->slurp_projects;
+    my $opt_parser = Getopt::Long::Parser->new( config => [ qw( no_auto_help pass_through ) ] );
+    $opt_parser->getoptions( "project=s" => \$project );
+
+    if (defined $project) {
+        if (my $project_config = $projects->{$project}) {
+            $self->project($project);
+            $dir = Path::Class::Dir->new($project_config);
+        } else {
+            my $error = "Cannot find project: $project\nKnown projects are:\n";
+            foreach (keys %$projects) {
+                $error .= "   ".$_."\n";
+            }
+            error_message($error);
+            exit;
+        }
+    }
 
     WALKUP: while (1) {
         my $config_file = $dir->file('.tracker.json');
+        my $this_config;
         if (-e $config_file) {
             push(@used_config_files, $config_file->stringify);
-            $config = merge($config, $self->slurp_config($config_file));
+            $this_config = $self->slurp_config($config_file);
+            $config = merge($config, $this_config);
 
             my @path = $config_file->parent->dir_list;
             my $project = $path[-1];
-            $self->config_file_locations->{$project}=$config_file->stringify;
+            $cfl->{$project}=$config_file->stringify;
+
+            $self->project($project)
+                unless $self->has_project;
 
-            $self->project($project) unless $self->has_project;
         }
         last WALKUP if $dir->parent eq $dir;
-        $dir = $dir->parent;
+
+        if (my $parent = $this_config->{'parent'}) {
+            if ($projects->{$parent}) {
+                $dir = Path::Class::file($projects->{$parent})->parent;
+                say $dir;
+            }
+            else {
+                $dir = $dir->parent;
+                say "Cannot find project >$parent< that's specified as a parent in $config_file";
+            }
+        }
+        else {
+            $dir = $dir->parent;
+        }
     }
 
-    $self->_write_config_file_locations;
+    $self->_write_config_file_locations($cfl);
 
     if (-e $self->global_config_file) {
         push(@used_config_files, $self->global_config_file->stringify);
@@ -129,32 +175,13 @@ sub load_config {
     }
     $config->{_used_config_files} = \@used_config_files;
 
-    unless ($self->has_project) {
-        $self->find_project_in_argv;
-    }
-
     return $config;
 }
 
-sub find_project_in_argv {
-    my $self = shift;
-
-    my @argv = @ARGV;
-    while (@argv) {
-        my $arg = shift(@argv);
-        if ($arg eq '--project') {
-            my $p = shift(@argv);
-            $self->project($p);
-            return;
-        }
-    }
-    $self->project('no_project');
-}
-
 sub _write_config_file_locations {
-    my $self = shift;
+    my ($self, $cfl) = @_;
     my $fh = $self->home->file('projects.json')->openw;
-    print $fh $self->json_decoder->encode($self->config_file_locations);
+    print $fh $self->json_decoder->encode($cfl || $self->config_file_locations);
     close $fh;
 }
 
@@ -165,11 +192,22 @@ sub slurp_config {
         return $self->json_decoder->decode( $content );
     }
     catch {
-        say "Cannot parse config file $file:\n$_";
+        error_message("Cannot parse config file $file:\n%s",$_);
         exit;
     };
 }
 
+sub slurp_projects {
+    my $self = shift;
+    my $file = $self->home->file('projects.json');
+    unless (-e $file && -s $file) {
+        error_message("Cannot find projects.json\n");
+        exit;
+    }
+    my $projects = decode_json($file->slurp);
+    return $projects;
+}
+
 1;
 
 
@@ -182,7 +220,7 @@ App::TimeTracker::Proto - App::TimeTracker Proto Class
 
 =head1 VERSION
 
-version 2.009
+version 2.010
 
 =head1 DESCRIPTION
 
